@@ -67,12 +67,12 @@ class PRS505(USBMS):
 
     EXTRA_CUSTOMIZATION_MESSAGE = [
         _('Comma separated list of metadata fields '
-            'to turn into collections on the device. Possibilities include: ')+
-        'series, tags, authors' +
-        _('. Two special collections are available: %(abt)s:%(abtv)s and %(aba)s:%(abav)s. Add  '
+            'to turn into collections on the device. Possibilities include: '
+            '%(coll)s. Two special collections are available: '
+            '%(abt)s:%(abtv)s and %(aba)s:%(abav)s. Add '
             'these values to the list to enable them. The collections will be '
             'given the name provided after the ":" character.')%dict(
-                            abt='abt', abtv=ALL_BY_TITLE, aba='aba', abav=ALL_BY_AUTHOR),
+            abt='abt', abtv=ALL_BY_TITLE, aba='aba', abav=ALL_BY_AUTHOR, coll='series, tags, authors'),
         _('Upload separate cover thumbnails for books (newer readers)') + ':::'+
         _('Normally, the SONY readers get the cover image from the'
                 ' e-book file itself. With this option, calibre will send a '
@@ -130,10 +130,10 @@ class PRS505(USBMS):
                     dname = os.path.dirname(cachep)
                     if not os.path.exists(dname):
                         try:
-                            os.makedirs(dname, mode=0777)
+                            os.makedirs(dname, mode=0o777)
                         except:
                             time.sleep(5)
-                            os.makedirs(dname, mode=0777)
+                            os.makedirs(dname, mode=0o777)
                     with lopen(cachep, 'wb') as f:
                         f.write(u'''<?xml version="1.0" encoding="UTF-8"?>
                             <cache xmlns="http://www.kinoma.com/FskCache/1">
